@@ -24,10 +24,6 @@ import_Thread_namespace()
 {
     ENTER ();
     static const struct fbuiltin_0 funcs_0[] = {
-        { do_Thread_cont, "cont", "i", "", "\n"
-	    " int cont ()\n"
-	    "\n"
-	    " Restarts any interrupted threads.\n" },
         { do_Thread_current, "current", "t", "", "\n"
 	    " thread current ()\n"
 	    "\n"
@@ -61,6 +57,11 @@ import_Thread_namespace()
 	    "\n"
 	    " Set 't's scheduling priority to 'priority'.\n"
 	    " Return 'priority.\n" },
+	{ do_Thread_signal, "send_signal", "v", "ti", "\n"
+	    " void signal (thread t, int signal)\n"
+	    "\n"
+	    " Raise the signal exception in thread 't'\n"
+	    " passing 'signal' as the argument\n" },
         { 0 }
     };
 
@@ -75,11 +76,20 @@ import_Thread_namespace()
         { 0 }
     };
 
+    static const struct ebuiltin excepts[] = {
+	{"signal",	exception_signal,	"i", "\n"
+	    " signal (int signal)\n"
+	    "\n"
+	    " Sent from the Thread::send_signal function.\n" },
+	{ 0 },
+    };
+
     ThreadNamespace = BuiltinNamespace (/*parent*/ 0, "Thread")->namespace.namespace;
 
     BuiltinFuncs0 (&ThreadNamespace, funcs_0);
     BuiltinFuncs1 (&ThreadNamespace, funcs_1);
     BuiltinFuncs2 (&ThreadNamespace, funcs_2);
     BuiltinFuncsV (&ThreadNamespace, funcs_v);
+    BuiltinExceptions (&ThreadNamespace, excepts);
     EXIT ();
 }
