@@ -920,7 +920,7 @@ int dump_inst = 0;
 
 #ifdef VALIDATE_EXECUTION
 
-extern DataType FrameType, BoxType, stackType, stackChunkType;
+extern DataType FrameType, BoxType, stackType, stackChunkType, ObjType;
 
 static void
 ObjValid(ObjPtr obj, InstPtr pc)
